==> koffice-1.2.1.tar.bz2: koffice-1.2.1/kpresenter/kpcubicbeziercurveobject.h <==
/* This file is part of the KDE project
   Copyright (C) 2001 Toshitaka Fujioka <fujioka@kde.org>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
*/

#ifndef kpcubicbeziercurveobject_h
#define kpcubicbeziercurveobject_h

#include <qpointarray.h>
#include "koPointArray.h"
#include <kpobject.h>
#include <koSize.h>

class QPainter;
class DCOPObject;

/******************************************************************/
/* Class: KPCubicBezierCurveObject                                */
/******************************************************************/

class KPCubicBezierCurveObject : public KPShadowObject
{
public:
    KPCubicBezierCurveObject();
    KPCubicBezierCurveObject( const KoPointArray &_controlPoints, const KoPointArray &_allPoints, const KoSize & _size,
                              const QPen &_pen, LineEnd _lineBegin, LineEnd _lineEnd );
    virtual ~KPCubicBezierCurveObject() {}

    virtual DCOPObject* dcopObject();

    KPCubicBezierCurveObject &operator=( const KPCubicBezierCurveObject & );

    virtual void setLineBegin( LineEnd _lineBegin ) { lineBegin = _lineBegin; }
    virtual void setLineEnd( LineEnd _lineEnd ) { lineEnd = _lineEnd; }

    virtual ObjType getType() const { return OT_CUBICBEZIERCURVE; }
    virtual QString getTypeString() const { return i18n("Cubic Bezier Curve"); }
    virtual LineEnd getLineBegin() const { return lineBegin; }
    virtual LineEnd getLineEnd() const { return lineEnd; }

    virtual QDomDocumentFragment save( QDomDocument& doc,double offset );
    virtual double load( const QDomElement &element );

    virtual void setSize( double _width, double _height );
    virtual void setSize( const KoSize & _size )
    { setSize( _size.width(), _size.height() ); }

    virtual void flip(bool horizontal );
    void closeObject(bool _close);
    bool isClosed()const;


protected:
    virtual void paint( QPainter *_painter,KoZoomHandler*_zoomHandler,
			bool drawingShadow, bool drawContour = FALSE );

    void updatePoints( double _fx, double _fy );

    KoPointArray getCubicBezierPointsFrom( const KoPointArray &_pointArray );

    KoPointArray origControlPoints, controlPoints;
    KoPointArray origAllPoints, allPoints;
    KoSize origSize;
    LineEnd lineBegin, lineEnd;
};

#endif

==> koffice-1.4.0a.tar.bz2: koffice-1.4.0a/kpresenter/kpcubicbeziercurveobject.h <==
// -*- Mode: c++; c-basic-offset: 4; indent-tabs-mode: nil; tab-width: 4; -*-
/* This file is part of the KDE project
   Copyright (C) 2001 Toshitaka Fujioka <fujioka@kde.org>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
*/

#ifndef kpcubicbeziercurveobject_h
#define kpcubicbeziercurveobject_h

#include "kppointobject.h"

class QPainter;
class DCOPObject;

class KPCubicBezierCurveObject : public KPPointObject
{
public:
    KPCubicBezierCurveObject();
    KPCubicBezierCurveObject( const KoPointArray &_controlPoints, const KoPointArray &_allPoints, const KoSize & _size,
                              const QPen &_pen, LineEnd _lineBegin, LineEnd _lineEnd );
    virtual ~KPCubicBezierCurveObject() {}

    virtual DCOPObject* dcopObject();

    KPCubicBezierCurveObject &operator=( const KPCubicBezierCurveObject & );

    virtual ObjType getType() const { return OT_CUBICBEZIERCURVE; }
    virtual QString getTypeString() const { return i18n("Cubic Bezier Curve"); }

    virtual QDomDocumentFragment save( QDomDocument& doc,double offset );
    virtual bool saveOasis( KoXmlWriter &xmlWriter, KoSavingContext& context, int indexObj ) const;

    virtual double load( const QDomElement &element );
    virtual void loadOasis( const QDomElement &element, KoOasisContext & context,KPRLoadingInfo* info   );

    virtual void flip(bool horizontal );
    void closeObject(bool _close);
    bool isClosed()const;


protected:
    virtual void updatePoints( double _fx, double _fy );
    virtual KoPointArray getDrawingPoints() const;

    KoPointArray getCubicBezierPointsFrom( const KoPointArray &_pointArray );

    KoPointArray allPoints;
};

#endif
